/**
 * サンプルプログラム2_csv: 『<biz-stream_home>/sample/java/Sample2_csv.java』
 * csvファイルをデータソースとしてPDFを生成するサンプルです。
 *
 * @author Copyright 2001-2022 BrainSellers.com Corp. All Rights Reserved
 * @version 1.1.0
 * @since 5.0.0
 */

import java.io.FileNotFoundException;
import java.io.IOException;

import com.brainsellers.pdf.PDFRuntimeException;
import com.brainsellers.xml.JaxpXML;
import com.brainsellers.xml.common.XMLSuper;

public class Sample2_csv {

	public static void main(String args[]) {
		new Sample2_csv(args);
		System.exit(0);
	}

	public Sample2_csv(String args[]) {
		try {
			// (1) 入出力共にファイル名で指定する
			XMLSuper xml = new JaxpXML(
					"${base-dir}/sample/java/Sample2_csv-doc.xml",
					"${base-dir}/sample/java/Sample2_csv.pdf");

			// (2) レイアウト情報(XML)の解析を行う
			xml.parse();

			// (3) 用紙サイズ、セキュリティ等の文書情報はドキュメントレイアウトで定義するので
			// アプリケーションでは設定しません。改ページ処理も必要ありません。

			// (4) ドキュメントレイアウトとは別のデータソースを指定してデータをマージし
			// PDFを出力する
			// ※第3引数はCSVファイルのエンコーディングを指定する
			xml.setDataSource("csv-resource","${base-dir}/sample/java/Sample2-other.csv", "UTF-8");

			// (4') 上記setDataSourceを行わなかった場合、
			// ドキュメントレイアウトで指定されているデータソースを使用してPDFを出力する

			// (5) 座標計算を行う
			xml.calcDataSize();

			// (6) PDFを生成する
			xml.toPDF();

			// (7) PDFを出力する
			xml.close();

		} catch (PDFRuntimeException e) {
			e.printStackTrace();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
